IntGenerator

Struct IntGenerator 

pub struct IntGenerator<T> { /* private fields */ }
Generator for integer types with optional range constraints

Implementations

Source

impl<T> IntGenerator<T>
where T: Copy + PartialOrd,

pub fn new(min: T, max: T) -> Self

Create a new integer generator with the full range for the type

Source

impl IntGenerator<i8>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<i16>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<i32>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<i64>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<i128>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<isize>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<u8>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<u16>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<u32>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<u64>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<u128>

pub fn full_range() -> Self

Create a generator for the full range of the type

Source

impl IntGenerator<usize>

pub fn full_range() -> Self

Create a generator for the full range of the type