Map

Struct Map 

pub struct Map<S, F> { /* private fields */ }
A strategy that maps values from one type to another

To enable proper shrinking through map, we need to store the original input alongside the mapped output. This is done using MappedValue.