pub struct IntGenerator<T> { /* private fields */ }Expand description
Generator for integer types with optional range constraints
Implementations
Sourceimpl<T> IntGenerator<T>where
T: Copy + PartialOrd,
impl<T> IntGenerator<T>where
T: Copy + PartialOrd,
Sourceimpl IntGenerator<i8>
impl IntGenerator<i8>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<i16>
impl IntGenerator<i16>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<i32>
impl IntGenerator<i32>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<i64>
impl IntGenerator<i64>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<i128>
impl IntGenerator<i128>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<isize>
impl IntGenerator<isize>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<u8>
impl IntGenerator<u8>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<u16>
impl IntGenerator<u16>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<u32>
impl IntGenerator<u32>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<u64>
impl IntGenerator<u64>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<u128>
impl IntGenerator<u128>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type
Sourceimpl IntGenerator<usize>
impl IntGenerator<usize>
Sourcepub fn full_range() -> Self
pub fn full_range() -> Self
Create a generator for the full range of the type